// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.math.MathUtil;
import edu.wpi.first.wpilibj.shuffleboard.Shuffleboard;
import edu.wpi.first.wpilibj.shuffleboard.ShuffleboardTab;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.Commands;
import edu.wpi.first.wpilibj2.command.RunCommand;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.Commands.Desaccumuler;
import frc.robot.Commands.FollowAprilTag;
import frc.robot.Commands.Lancer;
import frc.robot.Subsystems.Accumulateur;
import frc.robot.Subsystems.Drive;
import frc.robot.Subsystems.Lanceur;
import frc.robot.Subsystems.Limelight3G;

public class RobotContainer {
  Lanceur lanceur= new Lanceur();
  Accumulateur accumulateur = new Accumulateur();
  Limelight3G limelight3G = new Limelight3G();
  Drive drive = new Drive();
  ShuffleboardTab dashboard = Shuffleboard.getTab("dashboard");
  CommandXboxController manette = new CommandXboxController(0);
  public RobotContainer() {
    dashboard.addCamera("limelight3G", "limelight3G","limelight.local:5800")
    .withSize(4,3)
    .withPosition(0,0);
    dashboard.addCamera("limelight3", "limelight3","limelight.local:5800")
    .withSize(4,3)
    .withPosition(4,0);  
    configureBindings();
    drive.setDefaultCommand(new RunCommand(()->{
     drive.drive(-MathUtil.applyDeadband(manette.getRightX(),0.2), MathUtil.applyDeadband(-manette.getRightY(),0.2), MathUtil.applyDeadband(-manette.getRightX(), 0.2));
    },drive));
  }
  
  private void configureBindings() {

    manette.x().whileTrue(new Lancer(lanceur));
    manette.leftBumper().toggleOnTrue(new FollowAprilTag(limelight3G, lanceur));
    manette.a().whileTrue(new Desaccumuler(accumulateur));
  }

  public Command getAutonomousCommand() {
    return Commands.print("No autonomous command configured");
  }
}
